# HG changeset patch
# User Neil <nyamatongwe@gmail.com>
# Date 1520591697 -39600
#      Fri Mar 09 21:34:57 2018 +1100
# Node ID 8d8bb42dee442a7b56c8cec0c7002785ff314862
# Parent  9489f5f9cf14fa6433adb9a8968cd5ea71fd2d53
Templatize LineVector so it can later be switched between 32-bits and 64-bits.

diff -r 9489f5f9cf14 -r 8d8bb42dee44 src/CellBuffer.cxx
--- a/src/CellBuffer.cxx	Sat Mar 03 13:42:08 2018 +1100
+++ b/src/CellBuffer.cxx	Fri Mar 09 21:34:57 2018 +1100
@@ -45,8 +45,9 @@
 
 using namespace Scintilla;
 
+template <typename POS>
 class LineVector : public ILineVector {
-	Partitioning<int> starts;
+	Partitioning<POS> starts;
 	PerLine *perLine;
 public:
 	LineVector() : starts(256), perLine(0) {
@@ -65,10 +66,10 @@
 		perLine = pl;
 	}
 	void InsertText(Sci::Line line, Sci::Position delta) override {
-		starts.InsertText(line, delta);
+		starts.InsertText(static_cast<POS>(line), static_cast<POS>(delta));
 	}
 	void InsertLine(Sci::Line line, Sci::Position position, bool lineStart) override {
-		starts.InsertPartition(line, position);
+		starts.InsertPartition(static_cast<POS>(line), static_cast<POS>(position));
 		if (perLine) {
 			if ((line > 0) && lineStart)
 				line--;
@@ -76,10 +77,10 @@
 		}
 	}
 	void SetLineStart(Sci::Line line, Sci::Position position) override {
-		starts.SetPartitionStartPosition(line, position);
+		starts.SetPartitionStartPosition(static_cast<POS>(line), static_cast<POS>(position));
 	}
 	void RemoveLine(Sci::Line line) override {
-		starts.RemovePartition(line);
+		starts.RemovePartition(static_cast<POS>(line));
 		if (perLine) {
 			perLine->RemoveLine(line);
 		}
@@ -88,10 +89,10 @@
 		return starts.Partitions();
 	}
 	Sci::Line LineFromPosition(Sci::Position pos) const override {
-		return starts.PartitionFromPosition(pos);
+		return starts.PartitionFromPosition(static_cast<POS>(pos));
 	}
 	Sci::Position LineStart(Sci::Line line) const override {
-		return starts.PositionFromPartition(line);
+		return starts.PositionFromPartition(static_cast<POS>(line));
 	}
 };
 
@@ -368,7 +369,7 @@
 	readOnly = false;
 	utf8LineEnds = 0;
 	collectingUndo = true;
-	plv.reset(new LineVector());
+	plv.reset(new LineVector<Sci::Position>());
 }
 
 CellBuffer::~CellBuffer() {
